# aiogoogletrans fork

This is a fork of [googletrans](https://github.com/ssut/py-googletrans) with minor changes?

```
for further info and credits, lookup the original repo. Thanks :)
```

Available on pypi as granslate (`pip install granslate`)

(name inspired from gmail -> email)
